﻿<#
.SYNOPSIS
    以下のwebブラウザのパスを取得する。
    * Google Chrome
    * Mozilla Firefox
    * Microsoft edge
    * Microsoft edge(Chromium版)
    * Internet Explorer

.DESCRIPTION
    秀丸マクロ WebBrowserOpenSetup.mac から呼び出され、
    * Google Chrome
    * Mozilla Firefox
    * Microsoft edge
    * Microsoft edge(Chromium版)
    * Internet Explorer
   の 実行パスを取得し、iniファイル形式の設定ファイル「WebBrowserOpen.ini」を出力する。
.LINK
    http://htom.in.coocan.jp/macro/macro_etc.html
.NOTES
    出力ファイルは、UTF-16LE
.EXAMPLE
    WebBrowserOpenSetup.ps1 "出力フォルダのパス"
#>

Param([string]$path)
#引数のパスに移動
cd $path

#変数初期化
[int] $ini_cnt = 0
[string] $edgepath    = ""
[string] $firefoxpath = ""
[string] $chromepath  = ""
[string] $iepath      = ""
[string] $outfile     = "WebBrowserOpen.ini"

$ErrorActionPreference = "Stop"

# Internet Explorer のプロセスを検索し、パスを取得
try{
    $obj = get-process iexplore | select-object -First 1
    $iepath = $obj.path
} catch [Exception]{
} finally{
}

# Google Chrome のプロセスを検索し、パスを取得
try{
    $obj = get-process chrome | select-object -First 1
    $chromepath = $obj.path
} catch [Exception]{
} finally{
}

# Mozilla Firefox のプロセスを検索し、パスを取得
try{
    $obj = get-process firefox | select-object -First 1
    $firefoxpath = $obj.path
} catch [Exception]{
} finally{
}

#  Microsoft edge のプロセスを検索し、パスを取得
try{
    $obj = get-process MicrosoftEdge | select-object -First 1
    $edgepath = $obj.path
} catch [Exception]{
} finally{
}

#  Microsoft Edge(Chromium版) のプロセスを検索し、パスを取得
try{
    $obj = get-process msedge | select-object -First 1
    $chromiumedgepath = $obj.path
} catch [Exception]{
} finally{
}

# iniファイル形式のセクション追加
write-output "[browser]"|Out-File $outfile -Encoding unicode
# Firefox のパスが取得できていれば、キーとして追加
if ($firefoxpath -ne ""){
    write-output "name$ini_cnt=firefox" | Out-File $outfile -Encoding unicode -Append
    write-output "path$ini_cnt=$firefoxpath" | Out-File $outfile -Encoding unicode -Append
    write-output "windouclass$ini_cnt=MozillaWindowClass" | Out-File $outfile -Encoding unicode -Append
    $ini_cnt = $ini_cnt + 1
}

# Chrome のパスが取得できていれば、キーとして追加
if ($chromepath -ne ""){
    write-output "name$ini_cnt=Google Chrome" | Out-File $outfile -Encoding unicode -Append
    write-output "path$ini_cnt=$chromepath" | Out-File $outfile -Encoding unicode -Append
    write-output "windouclass$ini_cnt=Chrome_WidgetWin_1" | Out-File $outfile -Encoding unicode -Append
    $ini_cnt = $ini_cnt + 1
}

# Edge のパスが取得できていれば、(ストアアプリなので)加工してキーとして追加
if ($edgepath -ne ""){
    $edgepath = $edgepath -replace ".exe", ""
    $path_split = $edgepath -split "\\"
    $edgepath = "shell:AppsFolder\" + $path_split[$path_split.Length - 2] + "!" + $path_split[$path_split.Length - 1]
    write-output "name$ini_cnt=Microsoft Edge" | Out-File $outfile -Encoding unicode -Append
    write-output "path$ini_cnt=$edgepath" | Out-File $outfile -Encoding unicode -Append
    write-output "windouclass$ini_cnt=TabWindowClass" | Out-File $outfile -Encoding unicode -Append
    $ini_cnt = $ini_cnt + 1
}

# Microsoft Edge(Chromium版) のパスが取得できていれば、キーとして追加
if ($chromiumedgepath-ne ""){
    write-output "name$ini_cnt=Edge(Chromium)" | Out-File $outfile -Encoding unicode -Append
    write-output "path$ini_cnt=$chromiumedgepath" | Out-File $outfile -Encoding unicode -Append
    write-output "windouclass$ini_cnt=Chrome_WidgetWin_1" | Out-File $outfile -Encoding unicode -Append
    $ini_cnt = $ini_cnt + 1
}

# Internet Explorer のパスが取得できていれば、キーとして追加
if ($iepath -ne ""){
    write-output "name$ini_cnt=Internet explorer" | Out-File $outfile -Encoding unicode -Append
    write-output "path$ini_cnt=$iepath" | Out-File $outfile -Encoding unicode -Append
    write-output "windouclass$ini_cnt=IEFrame" | Out-File $outfile -Encoding unicode -Append
    $ini_cnt = $ini_cnt + 1
}

# 戻り値として 書き込んだブラウザの数を返す
exit $ini_cnt
